@@ -1,4 +1,7 @@
 package Net::Appliance::Session::Engine;
+BEGIN {
+  $Net::Appliance::Session::Engine::VERSION = '2.103641';
+}
 
 use strict;
 use warnings FATAL => 'all';
@@ -34,11 +37,16 @@ sub enable_paging {
     raise_error "Definition of 'paging_cmd' missing from phrasebook!"
         if ! eval {$self->pb->fetch('paging_cmd')};
 
-    $self->cmd(
-        $self->pb->fetch('paging_cmd') .' '. $self->get_pager_enable_lines
-    )
+    my $privstate = $self->in_privileged_mode;
+    $self->begin_privileged if $self->privileged_paging;
+
+    $self->cmd( $self->pb->fetch('paging_cmd')
+                .' '. $self->get_pager_enable_lines )
         or $self->error('Failed to enable paging');
 
+    $self->end_privileged
+        if $self->privileged_paging and not $privstate;
+
     return $self;
 }
 
@@ -50,11 +58,16 @@ sub disable_paging {
     raise_error "Definition of 'paging_cmd' missing from phrasebook!"
         if ! eval {$self->pb->fetch('paging_cmd')};
 
-    $self->cmd(
-        $self->pb->fetch('paging_cmd') .' '. $self->get_pager_disable_lines
-    )
+    my $privstate = $self->in_privileged_mode;
+    $self->begin_privileged if $self->privileged_paging;
+
+    $self->cmd( $self->pb->fetch('paging_cmd')
+                .' '. $self->get_pager_disable_lines )
         or $self->error('Failed to disable paging');
 
+    $self->end_privileged
+        if $self->privileged_paging and not $privstate;
+
     return $self;
 }
 
@@ -84,6 +97,12 @@ sub begin_privileged {
     raise_error 'Must connect before you can begin_privileged'
         unless $self->logged_in;
 
+    # rt.cpan#47214 check if we are already enabled by peeking the prompt
+    if ($self->last_prompt =~ eval 'qr'. $self->pb->fetch('privileged_prompt')) {
+        $self->in_privileged_mode(1);
+        return $self;
+    }
+
     # default is to reuse login credentials
     my $username = $self->get_username;
     my $password = $self->get_password;
@@ -193,6 +212,12 @@ sub begin_configure {
     raise_error 'Must enter privileged mode before configure mode'
         unless $self->in_privileged_mode;
 
+    # rt.cpan#47214 check if we are already in config by peeking the prompt
+    if ($self->last_prompt =~ eval 'qr'. $self->pb->fetch('configure_prompt')) {
+        $self->in_configure_mode(1);
+        return $self;
+    }
+
     # XXX: don't try to optimise away this print() and waitfor() into a cmd()
     # because they are needed to get the $match back!
 
